GlassBottomNavStyle class

Constructors

GlassBottomNavStyle({Color pillTint = const Color(0xFFFFFFFF), double pillBlurSigma = 46, double pillFilmStart = 0.26, double pillFilmEnd = 0.12, double pillBorderOpacity = 0.18, bool showSpecularDot = false, double pillFrostOpacity = 0.06, Color accent = const Color(0xFFFF2D55), double height = 68, double radius = 26, EdgeInsets barPadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 6), double widthFactor = 0.86, double edgePadding = 16, double selectedWidthFactor = 1, double selectedSideInsetPx = 1.5, double selectedHeightFactor = 1, double selectedInsetPx = 1, bool selectedCornerAuto = true, double selectedBlurSigma = 44, double selectedStartOpacity = 0.30, double selectedEndOpacity = 0.16, double selectedBorderOpacity = 0.26, double selectedFrostOpacity = 0.10, double selectedRadialOpacity = 0.14, double selectedRadialRadiusFactor = 0.90, Alignment selectedRadialCenter = const Alignment(-0.020, -0.20), double searchButtonSize = 54, double searchButtonBlur = 48, double searchButtonBorderWidth = 1.4, double searchGap = 12, IconData searchIcon = Icons.search_rounded})
const

Properties

accent Color
final
barPadding EdgeInsets
final
edgePadding double
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
pillBlurSigma double
final
pillBorderOpacity double
final
pillFilmEnd double
final
pillFilmStart double
final
pillFrostOpacity double
final
pillTint Color
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchButtonBlur double
final
searchButtonBorderWidth double
final
searchButtonSize double
final
searchGap double
final
searchIcon IconData
final
selectedBlurSigma double
final
selectedBorderOpacity double
final
selectedCornerAuto bool
final
selectedEndOpacity double
final
selectedFrostOpacity double
final
selectedHeightFactor double
final
selectedInsetPx double
final
selectedRadialCenter Alignment
final
selectedRadialOpacity double
final
selectedRadialRadiusFactor double
final
selectedSideInsetPx double
final
selectedStartOpacity double
final
selectedWidthFactor double
final
showSpecularDot bool
final
widthFactor double
final

Methods

copyWith({Color? pillTint, double? pillBlurSigma, double? pillFilmStart, double? pillFilmEnd, double? pillBorderOpacity, bool? showSpecularDot, double? pillFrostOpacity, Color? accent, double? height, double? radius, EdgeInsets? barPadding, double? widthFactor, double? edgePadding, double? selectedWidthFactor, double? selectedSideInsetPx, double? selectedHeightFactor, double? selectedInsetPx, bool? selectedCornerAuto, double? selectedBlurSigma, double? selectedStartOpacity, double? selectedEndOpacity, double? selectedBorderOpacity, double? selectedFrostOpacity, double? selectedRadialOpacity, double? selectedRadialRadiusFactor, Alignment? selectedRadialCenter, double? searchButtonSize, double? searchButtonBlur, double? searchButtonBorderWidth, double? searchGap, IconData? searchIcon}) GlassBottomNavStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited